==> spigot-api-1.21.2-R0.1-20241022.210936-4-sources.jar: org/bukkit/inventory/TransmuteRecipe.java <==
package org.bukkit.inventory;

import org.bukkit.Material;
import org.bukkit.NamespacedKey;
import org.jetbrains.annotations.NotNull;

/**
 * Represents a recipe which will change the type of the input material when
 * combined with an additional material, but preserve all custom data. Only the
 * item type of the result stack will be used.
 * <br>
 * Used for dyeing shulker boxes in Vanilla.
 */
public class TransmuteRecipe extends CraftingRecipe implements ComplexRecipe {

    private final RecipeChoice input;
    private final RecipeChoice material;

    /**
     * Create a transmute recipe to produce a result of the specified type.
     *
     * @param key the unique recipe key
     * @param result the transmuted result material
     * @param input the input ingredient
     * @param material the additional ingredient
     */
    public TransmuteRecipe(@NotNull NamespacedKey key, @NotNull Material result, @NotNull RecipeChoice input, @NotNull RecipeChoice material) {
        super(key, checkResult(new ItemStack(result)));
        this.input = input;
        this.material = material;
    }

    /**
     * Gets the input material, which will be transmuted.
     *
     * @return the input from transmutation
     */
    @NotNull
    public RecipeChoice getInput() {
        return input.clone();
    }

    /**
     * Gets the additional material required to cause the transmutation.
     *
     * @return the ingredient material
     */
    @NotNull
    public RecipeChoice getMaterial() {
        return material.clone();
    }
}

==> spigot-api-1.21.11-R0.2-20260201.050842-7-sources.jar: org/bukkit/inventory/TransmuteRecipe.java <==
package org.bukkit.inventory;

import org.bukkit.Material;
import org.bukkit.NamespacedKey;
import org.jetbrains.annotations.NotNull;

/**
 * Represents a recipe which will change the type of the input material when
 * combined with an additional material, but preserve all custom data. Only the
 * item type of the result stack will be used.
 * <br>
 * Used for dyeing shulker boxes in Vanilla.
 */
public class TransmuteRecipe extends CraftingRecipe implements ComplexRecipe {

    private final RecipeChoice input;
    private final RecipeChoice material;

    /**
     * Create a transmute recipe to produce a result of the specified type.
     *
     * @param key the unique recipe key
     * @param result the transmuted result item
     * @param input the input ingredient
     * @param material the additional ingredient
     */
    public TransmuteRecipe(@NotNull NamespacedKey key, @NotNull ItemStack result, @NotNull RecipeChoice input, @NotNull RecipeChoice material) {
        super(key, checkResult(result));
        this.input = input;
        this.material = material;
    }

    /**
     * Create a transmute recipe to produce a result of the specified type.
     *
     * @param key the unique recipe key
     * @param result the transmuted result material
     * @param input the input ingredient
     * @param material the additional ingredient
     */
    public TransmuteRecipe(@NotNull NamespacedKey key, @NotNull Material result, @NotNull RecipeChoice input, @NotNull RecipeChoice material) {
        this(key, new ItemStack(result), input, material);
    }

    /**
     * Gets the input material, which will be transmuted.
     *
     * @return the input from transmutation
     */
    @NotNull
    public RecipeChoice getInput() {
        return input.clone();
    }

    /**
     * Gets the additional material required to cause the transmutation.
     *
     * @return the ingredient material
     */
    @NotNull
    public RecipeChoice getMaterial() {
        return material.clone();
    }
}
